import builtins
import inspect
import os

class EddmPrint:
    def __init__(self, color=None, prefixTemplate=None):
        self.originalPrint = print
        self.color = color or "\033[35m"
        self.prefixTemplate = prefixTemplate or "[파일명: {file} | 함수명: {func} | 라인: {line}]"
        self.reset = "\033[0m"
        self.isActive = False

    def start(self):
        if not self.isActive:
            builtins.print = self._wrappedPrint
            self.isActive = True

    def restore(self):
        if self.isActive:
            builtins.print = self.originalPrint
            self.isActive = False

    def setColor(self, colorCode):
        self.color = colorCode

    def setPrefixTemplate(self, template):
        self.prefixTemplate = template

    def _wrappedPrint(self, *args, **kwargs):
        frame = inspect.stack()[1]
        file = os.path.basename(frame.filename)
        func = frame.function
        line = frame.lineno
        prefix = f"{self.color}{self.prefixTemplate.format(file=file, func=func, line=line)}{self.reset}"
        self.originalPrint(prefix, *args, **kwargs)



from .printer import EddmPrint
from .colors import Colors
from .templates import Templates

__version__ = "0.1.2"
__all__ = ["EddmPrint", "Colors", "Templates", "printer"]

# 기본 인스턴스 생성 및 시작
printer = EddmPrint()
printer.start()


from setuptools import setup, find_packages

setup(
    name="eddmPrint",
    version="0.1.2",
    packages=find_packages(), 
    install_requires=[],
    author="eddmpython",
    author_email="eddmpython@gmail.com",
    description="색상과 위치 정보가 포함된 개선된 프린트 라이브러리",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/eddmpython/eddmPrint",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
) 